@@ -12,7 +12,7 @@ import os.path as osp
 
 from xdis.version import VERSION
 from xdis import PYTHON_VERSION
-from xdis.main import disassemble_file
+from xdis import disassemble_file
 
 program, ext = os.path.splitext(os.path.basename(__file__))
 
@@ -65,7 +65,7 @@ def main(asm, show_bytes, header, files):
         elif not osp.isfile(path):
             sys.stderr.write("File name: '%s' isn't a file\n" % path)
             continue
-        elif osp.getsize(path) < 50:
+        elif osp.getsize(path) < 50 and not path.endswith(".py"):
             sys.stderr.write(
                 "File name: '%s (%d bytes)' is too short to be a valid pyc file\n"
                 % (path, osp.getsize(path))
