@@ -22,7 +22,7 @@ of stack usage.
 
 from xdis.opcodes.base import(
     def_op, finalize_opcodes,
-    init_opdata, jrel_op, name_op,
+    init_opdata, jrel_op,
     nargs_op, rm_op, store_op, varargs_op,
     update_pj3
     )
@@ -35,6 +35,7 @@ import xdis.opcodes.opcode_35 as opcode_35
 EXTENDED_ARG_SHIFT = 8
 
 version = 3.6
+python_implementation = "CPython"
 
 l = locals()
 
@@ -102,6 +103,8 @@ varargs_op(l,  'BUILD_TUPLE_UNPACK_WITH_CALL', 158)
 MAKE_FUNCTION_FLAGS = tuple("default keyword-only annotation closure".split())
 
 def format_MAKE_FUNCTION_arg(flags):
+    if flags == 0:
+        return "No defaults, keyword-only args, annotations, or closures"
     pattr = ''
     for flag in MAKE_FUNCTION_FLAGS:
         bit = flags & 1
@@ -132,16 +135,27 @@ def format_value_flags(flags):
 def format_extended_arg36(arg):
     return str(arg * (1 << 8))
 
+def format_CALL_FUNCTION(argc):
+    """argc indicates the number of positional arguments"""
+    if argc == 1:
+        plural = ""
+    else:
+        plural = "s"
+    return ("%d positional argument%s" % (argc, plural))
+
 def format_CALL_FUNCTION_EX(flags):
     str = ""
     if flags & 0x01:
-        str = "keyword args"
+        str = "keyword and positional arguments"
+    else:
+        str = "positional arguments only"
     return str
 
 def format_CALL_FUNCTION_KW(argc):
     return "%d total positional and keyword args" % argc
 
 opcode_arg_fmt = {
+    'CALL_FUNCTION': format_CALL_FUNCTION,
     'CALL_FUNCTION_KW': format_CALL_FUNCTION_KW,
     'CALL_FUNCTION_EX': format_CALL_FUNCTION_EX,
     'MAKE_FUNCTION': format_MAKE_FUNCTION_arg,
